@@ -1497,7 +1497,8 @@ void EditorTab::mergeIntoOpenDocument()
     QString xliff2odf=QStringLiteral("xliff2odf");
     if (QProcess::execute(xliff2odf, QStringList("--version"))==-2)
     {
-        KMessageBox::error(SettingsController::instance()->mainWindowPtr(), i18n("Install translate-toolkit package and retry"));
+        KMessageBox::error(SettingsController::instance()->mainWindowPtr(),
+                           i18n("Install translate-toolkit package and retry."));
         return;
     }
     QString xliffFolder=QFileInfo(m_catalog->url()).absolutePath();
@@ -1505,8 +1506,11 @@ void EditorTab::mergeIntoOpenDocument()
     QString originalOdfFilePath=m_catalog->originalOdfFilePath();
     if (originalOdfFilePath.isEmpty() || !QFile::exists(originalOdfFilePath))
     {
-        originalOdfFilePath=QFileDialog::getOpenFileName(SettingsController::instance()->mainWindowPtr(), i18n("Select original OpenDocument on which current XLIFF file is based"), xliffFolder,
-                                          i18n("OpenDocument files (*.odt *.ods)")/*"text/x-lokalize-project"*/);
+        originalOdfFilePath=QFileDialog::getOpenFileName(
+            SettingsController::instance()->mainWindowPtr(),
+            i18n("Select original OpenDocument on which current XLIFF file is based"),
+            xliffFolder,
+            i18n("OpenDocument files (*.odt *.ods)")/*"text/x-lokalize-project"*/);
         if (originalOdfFilePath.length()) m_catalog->setOriginalOdfFilePath(originalOdfFilePath);
     }
     if (originalOdfFilePath.isEmpty())
@@ -1546,7 +1550,8 @@ void EditorTab::mergeIntoOpenDocument()
             QStringList unoArgs(QStringLiteral("-c")); unoArgs.append(QStringLiteral("import uno"));
             if (QProcess::execute(python, unoArgs)!=0)
             {
-                KMessageBox::information(SettingsController::instance()->mainWindowPtr(), i18n("Install python-uno package for additional functionality"));
+                KMessageBox::information(SettingsController::instance()->mainWindowPtr(),
+                                         i18n("Install python-uno package for additional functionality."));
                 return;
             }
 
